@@ -4,7 +4,7 @@ import os
 import Image, ImageEnhance
 import ImageDraw
 import ImageFont
-#from PyQt4.QtMaemo5 import QMaemo5InformationBox
+from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from PyQt4 import QtGui,QtCore
 from PyQt4.QtGui import QIcon
 from shortcutmkr import *
@@ -13,7 +13,6 @@ num = ('')
 ico = ('')
 new = ('')
 
-
 class MyForm(QtGui.QMainWindow):
 	def __init__(self, parent=None):
 		#build parent user interface
@@ -21,7 +20,7 @@ class MyForm(QtGui.QMainWindow):
 		self.ui = Ui_ShortcutMaker()
 		self.ui.setupUi(self)
 		self.initUI()
-				
+		self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/hicolor/48x48/hildon/general_sms.png')))		
 		
 	def initUI(self):
         	self.setWindowTitle('Shortcut Maker')
@@ -62,6 +61,36 @@ class MyForm(QtGui.QMainWindow):
 			self.ui.lineEdit_4.setText(self.ui.lineEdit.text()) 
 			self.ui.lineEdit_5.setText(self.ui.lineEdit_2.text())
                         self.ui.lineEdit_6.setText(self.ui.lineEdit.text())
+		if self.ui.tabWidget.currentIndex() is  0:
+			if self.ui.lineEdit_3.isModified(): self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
+
+			else: self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/hicolor/48x48/hildon/general_sms.png')))
+		if self.ui.tabWidget.currentIndex() is  1:
+			if self.ui.lineEdit_3.isModified(): self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
+
+			else: self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/hicolor/48x48/hildon/general_call.png')))
+		if self.ui.tabWidget.currentIndex() is  2:
+			if self.ui.lineEdit_3.isModified(): self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
+
+			else: self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/hicolor/48x48/hildon/general_email.png')))
+		if self.ui.tabWidget.currentIndex() is  3:
+			if self.ui.lineEdit_3.isModified(): self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
+
+			else: self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/hicolor/48x48/hildon/filemanager_file_loading.png')))
+		if self.ui.tabWidget.currentIndex() is  4:
+			if self.ui.lineEdit_3.isModified(): self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
+
+			else: self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/hicolor/48x48/hildon/general_delete.png')))
+		if self.ui.tabWidget.currentIndex() is  5:
+			if self.ui.lineEdit_3.isModified(): self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
+
+			else: self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/hicolor/48x48/hildon/general_add.png')))
+
+
+
+
+
+
 #endtabchange	
 
 
@@ -94,7 +123,7 @@ Icon='''+sm+'''''',
 			fsock.close()
 			contact = ('')
 			num = ('')	
-#			QMaemo5InformationBox.information(self,"SMS Shortcut Created")
+			QMaemo5InformationBox.information(self,"SMS Shortcut Created")
 
 		if self.ui.tabWidget.currentIndex() is  1:
 			if self.ui.lineEdit_3.isModified():
@@ -123,7 +152,7 @@ Icon='''+sm+''''''
 			fsock3.close()
 			contact = ('')
 			num = ('')
-#			QMaemo5InformationBox.information(self,"Call Shortcut Created")
+			QMaemo5InformationBox.information(self,"Call Shortcut Created")
 
 
 		if self.ui.tabWidget.currentIndex() is  2:
@@ -153,7 +182,7 @@ Icon='''+sm+''''''
 			fsock2.close()
 			contact = ('')
 			num = ('')
-#			QMaemo5InformationBox.information(self,"Email Shortcut Created")
+			QMaemo5InformationBox.information(self,"Email Shortcut Created")
 
 		if self.ui.tabWidget.currentIndex() is  3:
 			if self.ui.lineEdit_3.isModified():
@@ -186,7 +215,7 @@ Icon='''+sm+''''''
 			fsock4.close()
 			contact = ('')
 			num = ('')
-#			QMaemo5InformationBox.information(self,"Command Shortcut Created")
+			QMaemo5InformationBox.information(self,"Command Shortcut Created")
 
 
 
@@ -246,33 +275,33 @@ Icon='''+sm+''''''
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
-#			QMaemo5InformationBox.information(self,"Shortcut Deleted")
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		if self.ui.checkBox_3.isChecked():
 			contact = self.ui.lineEdit_10.text()
 			os.remove('/usr/share/applications/hildon/phone'+contact+'.desktop')
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
-#			QMaemo5InformationBox.information(self,"Shortcut Deleted")
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		if self.ui.checkBox_4.isChecked():
 			contact = self.ui.lineEdit_10.text()
 			os.remove('/usr/share/applications/hildon/email'+contact+'.desktop')
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
-#			QMaemo5InformationBox.information(self,"Shortcut Deleted")
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		if self.ui.checkBox_5.isChecked():
 			contact = self.ui.lineEdit_10.text()
 			os.remove('/usr/share/applications/hildon/cmd'+contact+'.desktop')
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
-#			QMaemo5InformationBox.information(self,"Shortcut Deleted")
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		self.ui.checkBox_2.setChecked(False)
 		self.ui.checkBox_3.setChecked(False)
 		self.ui.checkBox_4.setChecked(False)
 		self.ui.checkBox_5.setChecked(False)
-#		QMaemo5InformationBox.information(self,"Shortcut Deleted")
+		QMaemo5InformationBox.information(self,"Shortcut Deleted")
 
 	
 #end button actions
@@ -285,25 +314,14 @@ Icon='''+sm+''''''
 		self.ui.lineEdit_16.setText(fontn)
 	
 
-	def doSelecticon(self):
-		filename = QtGui.QFileDialog.getOpenFileName(self, 'Open file',
-                    '/usr/share/icons/')
-		fname = open(filename)
-		filen = (filename)
-		#filen = filename.split(".")[0].split("/")[-1] 
-		self.ui.lineEdit_3.setText(filen)
-		self.ui.label_3.setPixmap(QtGui.QPixmap((filename)));
-		self.ui.lineEdit_3.setModified(True)
-#		QMaemo5InformationBox.information(self,"Icon Selected")
-
-	
-				
+			
 	
 	def doIcontext(self):
 		r = int(self.ui.lineEdit_13.text())
 		g = int(self.ui.lineEdit_14.text())
 		b = int(self.ui.lineEdit_15.text())	
 		icon = str(self.ui.lineEdit_3.text())
+		global mytext		
 		mytext = str(self.ui.lineEdit_11.text())
 		
 
@@ -351,9 +369,21 @@ Icon='''+sm+''''''
 		self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
 		self.ui.lineEdit_3.setModified(True)
 		
-#		QMaemo5InformationBox.information(self,"Icon Created")
-	
+		QMaemo5InformationBox.information(self,"Icon Created")
 	
+	def doSelecticon(self):
+		filename = QtGui.QFileDialog.getOpenFileName(self, 'Open file',
+                    '/usr/share/icons/')
+		fname = open(filename)
+		filen = (filename)
+		#filen = filename.split(".")[0].split("/")[-1] 	
+		self.ui.lineEdit_3.setText(filen)
+		global mytext
+		mytext = self.ui.lineEdit_3
+		self.ui.label_3.setPixmap(QtGui.QPixmap((filename)));
+		self.ui.lineEdit_3.setModified(True)
+		QMaemo5InformationBox.information(self,"Icon Selected")	
+
 
 	def doIcondelete(self):
 		os.remove(self.ui.lineEdit_3.text())
@@ -362,7 +392,7 @@ Icon='''+sm+''''''
 		self.ui.label_3.clear()
 		self.ui.lineEdit_3.setModified(False)
 		
-#		QMaemo5InformationBox.information(self,"Icon Deleted")
+		QMaemo5InformationBox.information(self,"Icon Deleted")
 if __name__ == "__main__":
 	app = QtGui.QApplication(sys.argv)
 	myapp = MyForm()
